pub struct RiServiceInstance {
pub id: String,
pub service_name: String,
pub host: String,
pub port: u16,
pub metadata: HashMap<String, String>,
pub registered_at: SystemTime,
pub last_heartbeat: SystemTime,
pub status: RiServiceStatus,
}Fields
id: Stringservice_name: Stringhost: Stringport: u16metadata: HashMap<String, String>registered_at: SystemTimelast_heartbeat: SystemTimestatus: RiServiceStatusTrait Implementations
Sourceimpl Clone for RiServiceInstance
impl Clone for RiServiceInstance
Sourcefn clone(&self) -> RiServiceInstance
fn clone(&self) -> RiServiceInstance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiServiceInstance
impl Debug for RiServiceInstance
Sourceimpl<'de> Deserialize<'de> for RiServiceInstance
impl<'de> Deserialize<'de> for RiServiceInstance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for RiServiceInstance
impl<'py> IntoPyObject<'py> for RiServiceInstance
Sourcetype Target = RiServiceInstance
type Target = RiServiceInstance
The Python output type
Sourcetype Output = Bound<'py, <RiServiceInstance as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <RiServiceInstance as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for RiServiceInstance
impl PyClass for RiServiceInstance
Sourceimpl PyClassImpl for RiServiceInstance
impl PyClassImpl for RiServiceInstance
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<RiServiceInstance>
type ThreadChecker = SendablePyClass<RiServiceInstance>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for RiServiceInstance
impl PyClassNewTextSignature for RiServiceInstance
const TEXT_SIGNATURE: &'static str = "(id, service_name, host, port)"
Sourceimpl PyMethods<RiServiceInstance> for PyClassImplCollector<RiServiceInstance>
impl PyMethods<RiServiceInstance> for PyClassImplCollector<RiServiceInstance>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for RiServiceInstance
impl PyTypeInfo for RiServiceInstance
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for RiServiceInstance
impl Serialize for RiServiceInstance
impl DerefToPyAny for RiServiceInstance
impl ExtractPyClassWithClone for RiServiceInstance